library(survival)
library(dplyr)
library(survminer)
library(stargazer)
library(ggplot2)

###### OPEN DATA FILES ######

setwd(dirname(rstudioapi::getSourceEditorContext()$path))
io_data <- read.csv("io_data.csv")

#membership form
io_data$memb_formc <- ifelse(io_data$memb_form == 1, 'open', NA)
io_data$memb_formc <- ifelse(io_data$memb_form == 2, 'geo_resticted', io_data$memb_formc)
io_data$memb_formc <- ifelse(io_data$memb_form == 3, 'purp_resticted', io_data$memb_formc)
io_data$memb_formc <- as.factor(io_data$memb_formc)



######### MODELS ############
##Cox model
#model

io_data[8,13] <- 'economic'
io_data$function_c <- droplevels(io_data$function_c)



io_data$membership_growth <- io_data$full_membership_end - io_data$full_membership_start

io_data1 <- io_data[-83,] 
io_data$memb_form <- as.factor(io_data$memb_form)

io_data$Global <- ifelse(io_data$region_c == "Global", 0,1 )
io_data$region_c = factor(io_data$region_c,levels(io_data$region_c)[c(5,1:4, 6:7)])


write.csv(io_data, "final_dataset.csv")


coxph <- coxph(Surv(life,event) ~ full_membership_end + region_c + function_c + scope_c, data = io_data, method="breslow")

summary(coxph)

### Table 1 model specification ####
coxphT1_succ1 <- coxph(Surv(life,event) ~ full_membership_end  + region_c + function_c  + memb_formc + scope_c  , data = io_data, method="breslow")
coxphT1_succ2 <- coxph(Surv(life_1,event_1) ~ full_membership_end  + region_c + function_c  + memb_formc + scope_c  , data = io_data, method="breslow")

#coxph1 <- coxph(Surv(life_1,event_1) ~  full_membership_end + full_membership_start  + region_c + function_c  + scope_c  + WW , data = io_data, method="breslow")
#coxph4 <- coxph(Surv(life_1,event_1) ~  full_membership_end  + region_c + function_c  + scope_c, data = io_data, method="breslow")
#coxph5 <- coxph(Surv(life,event) ~ full_membership_end + membership_growth + region_c + function_c  + scope_c, data = io_data, method="breslow")
#coxph6 <- coxph(Surv(life_1,event_1) ~  full_membership_end  + membership_growth  +region_c + function_c  + scope_c, data = io_data, method="breslow")

options(scipen=999)
write.csv(data.frame(summary(coxphT1_succ1)$coefficients), "succ=death.csv")
write.csv(data.frame(summary(coxphT1_succ2)$coefficients), "succ=living.csv")


#write.csv(data.frame(summary(coxph1)$coefficients), "succ=death_end.csv")
#write.csv(data.frame(summary(coxph4)$coefficients), "succ=living_end.csv")
#write.csv(data.frame(summary(coxph5)$coefficients), "succ=death_end_growth.csv")
#write.csv(data.frame(summary(coxph6)$coefficients), "succ=living_end_growth.csv")


### Baseline hazard plot ####

baseline <- basehaz(coxphT1_succ1)
baseline1 <- basehaz(coxphT1_succ2)
plot(baseline$time, baseline$hazard, type='l',main="Cummulative Hazard rates") 

#names(baseline) <- c("hazard_1", "time")
#names(baseline1) <- c("hazard_2", "time")

baseline$model <- 1
baseline1$model <- 2

baselines_test <- rbind(baseline, baseline1)

baselines <- left_join(baseline, baseline1)

base_line_hazard <- ggplot(baselines_test, aes(time, hazard, colour = factor(model))) + 
      geom_line() + 
      labs(x="Time",y="Baseline hazard") + 
      theme(plot.title = element_text( color="#666666", face="bold", size=22, hjust=0)) +
      theme(axis.title = element_text( color="#666666", face="bold", size=22)) 
 

pdf('base_line_hazard.pdf',  onefile=T, paper='A4r', width = 10)
base_line_hazard
dev.off()

##### alternative plots ###
ggplot(baseline, aes(time, hazard)) + geom_line() 


cox.fit <- survfit(coxph, data = io_data)
p <- ggsurvplot(cox.fit, risk.table = TRUE)
p

p <- ggsurv(cox.fit)
p



##Weibull model
#model
weibull <- survreg(Surv(life,event) ~ members_censor +  function_c + region + WW + memb_form + scope_c , data = io_data, dist="weibull")
summary(weibull)

# Plot

weibull.fit <- survfit(weibull, data = io_data)

intercept<- summary(weibull)$coefficients[['(Intercept)']]
scale<- weibull$scale

par(mfrow=c(1,2),mar=c(5.1,5.1,4.1,2.1)) # Make room for the hat.
# S(t), the survival function
curve(pweibull(x, scale=exp(intercept), shape=1/scale, lower.tail=FALSE), 
      from=0, to=200, col='red', lwd=2, ylab=expression(hat(S)(t)), xlab='t',bty='n',ylim=c(0,1))
# h(t), the hazard function
curve(dweibull(x, scale=exp(intercept), shape=1/scale)
      /pweibull(x, scale=exp(intercept), shape=1/scale, lower.tail=FALSE), 
      from=0, to=200, col='blue', lwd=2, ylab=expression(hat(h)(t)), xlab='t',bty='n')
par(mfrow=c(1,1),mar=c(5.1,4.1,4.1,2.1))

WeibullDiag(Surv(life, event) ~ factor(scope_c), data = io_data)


# Kaplan-Meier non-parametric analysis
kmsurvival <- survfit(Surv(life,event) ~ 1, data=io_data)
kmsurvival1 <- survfit(Surv(life_1,event_1) ~ 1, data=io_data)


p <- ggsurvplot(kmsurvival, risk.table = TRUE)
p1 <- ggsurvplot(kmsurvival1, risk.table = TRUE)

pdf('KM_0.pdf',  onefile=T, paper='A4r', width = 10)
p
dev.off()

pdf('KM_1.pdf',  onefile=T, paper='A4r', width=10)
p1
dev.off()

# Kaplan-Meier non-parametric analysis by group

kmsurvival <- survfit(Surv(life, event) ~ memb_formc, data=io_data1)
kmsurvival1 <- survfit(Surv(life_1, event_1) ~ region_c, data=io_data)

p <- ggsurvplot(kmsurvival, risk.table = TRUE) 
p
p1 <- ggsurvplot(kmsurvival1, risk.table = TRUE)

pdf('KM_region_0.pdf',  onefile=T, paper='A4r', width = 10)
p
dev.off()

pdf('KM_region_1.pdf',  onefile=T, paper='A4r', width = 10)
p1
dev.off()

ggsurvplot(
  kmsurvival1,                     # survfit object with calculated statistics.
  risk.table = TRUE,       # show risk table.
  pval = TRUE,             # show p-value of log-rank test.
  conf.int = TRUE,         # show confidence intervals for 
  # point estimaes of survival curves.
  xlim = c(0,200),        # present narrower X axis, but not affect
  # survival estimates.
  break.time.by = 10,     # break X axis in time intervals by 500.
   # customize plot and risk table with a theme.
  risk.table.y.text.col = T, # colour risk table text annotations.
  risk.table.y.text = FALSE # show bars instead of names in text annotations
  # in legend of risk table
)





